{-# LANGUAGE DataKinds #-}
{-# LANGUAGE DeriveGeneric #-}
{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE TypeOperators #-}

module Type where

import Control.Monad.IO.Class
import Data.Proxy
import Multipart
import Network.HTTP.Client (newManager, Manager, defaultManagerSettings)
import Servant.API
import Servant.API.ContentTypes
import Servant.Client
import Servant.Multipart
import System.Environment

import qualified Data.ByteString.Lazy as LBS
import qualified Data.Text as T

-- was MultipartData Mem
type GrobidAPI =
  "processHeaderDocument" :> MultipartForm Tmp (MultipartData Mem) :> Post '[PlainText] T.Text
  :<|> "process" :> MultipartForm Tmp (MultipartData Mem) :> Post '[PlainText] T.Text

-- processHeaderDocument :: FilePath -> ClientM T.Text
processHeaderDocument :: MultipartData Mem -> ClientM T.Text
process :: MultipartData Mem -> ClientM T.Text

grobidAPI :: Proxy GrobidAPI
grobidAPI = Proxy

processHeaderDocument :<|> process = client grobidAPI

-- fileTest :: FilePath
-- fileTest = "/home/mudada/Code/Haskell/grobid-binding/files"

queries :: FilePath -> IO (Either ServantError T.Text)
queries filePath = do
  fileContents <- liftIO $ LBS.readFile filePath
  manager <- newManager defaultManagerSettings
  let
    fileData = FileData
      { fdInputName = "input"
      , fdFileName  = T.pack filePath
      , fdFileCType = "application/pdf"
      , fdPayload   = fileContents
      }
    multipartData = MultipartData
      { inputs = []
      , files = [fileData]
      }
    c = processHeaderDocument multipartData
    baseUrl = BaseUrl Http "localhost" 8080 ""
    env = mkClientEnv manager baseUrl
  runClientM c env
